"""
PhenoFetch - Command-line tool for downloading PhenoCam data

Copyright 2025 Samapriya Roy

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import json


def site_all():
    return {
        "data": {
            "sites": [
                {
                    "siteCode": "ABBY",
                    "siteDescription": "Abby Road NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 45.762439,
                    "siteLongitude": -122.330317,
                    "domainCode": "D16",
                    "stateCode": "WA",
                },
                {
                    "siteCode": "ARIK",
                    "siteDescription": "Arikaree River NEON",
                    "siteType": "CORE",
                    "siteLatitude": 39.758206,
                    "siteLongitude": -102.447148,
                    "domainCode": "D10",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "BARC",
                    "siteDescription": "Lake Barco NEON",
                    "siteType": "CORE",
                    "siteLatitude": 29.675982,
                    "siteLongitude": -82.008414,
                    "domainCode": "D03",
                    "stateCode": "FL",
                },
                {
                    "siteCode": "BARR",
                    "siteDescription": "Utqiaġvik NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 71.28241,
                    "siteLongitude": -156.61936,
                    "domainCode": "D18",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "BART",
                    "siteDescription": "Bartlett Experimental Forest NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 44.063889,
                    "siteLongitude": -71.287375,
                    "domainCode": "D01",
                    "stateCode": "NH",
                },
                {
                    "siteCode": "BIGC",
                    "siteDescription": "Upper Big Creek NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 37.059719,
                    "siteLongitude": -119.257549,
                    "domainCode": "D17",
                    "stateCode": "CA",
                },
                {
                    "siteCode": "BLAN",
                    "siteDescription": "Blandy Experimental Farm NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 39.033698,
                    "siteLongitude": -78.041788,
                    "domainCode": "D02",
                    "stateCode": "VA",
                },
                {
                    "siteCode": "BLDE",
                    "siteDescription": "Blacktail Deer Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 44.95011,
                    "siteLongitude": -110.58715,
                    "domainCode": "D12",
                    "stateCode": "WY",
                },
                {
                    "siteCode": "BLUE",
                    "siteDescription": "Blue River NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 34.444218,
                    "siteLongitude": -96.624201,
                    "domainCode": "D11",
                    "stateCode": "OK",
                },
                {
                    "siteCode": "BLWA",
                    "siteDescription": "Black Warrior River NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 32.541529,
                    "siteLongitude": -87.798151,
                    "domainCode": "D08",
                    "stateCode": "AL",
                },
                {
                    "siteCode": "BONA",
                    "siteDescription": "Caribou-Poker Creeks Research Watershed NEON",
                    "siteType": "CORE",
                    "siteLatitude": 65.15401,
                    "siteLongitude": -147.50258,
                    "domainCode": "D19",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "CARI",
                    "siteDescription": "Caribou Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 65.153224,
                    "siteLongitude": -147.503973,
                    "domainCode": "D19",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "CLBJ",
                    "siteDescription": "Lyndon B. Johnson National Grassland NEON",
                    "siteType": "CORE",
                    "siteLatitude": 33.40123,
                    "siteLongitude": -97.57,
                    "domainCode": "D11",
                    "stateCode": "TX",
                },
                {
                    "siteCode": "COMO",
                    "siteDescription": "Como Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 40.034962,
                    "siteLongitude": -105.544164,
                    "domainCode": "D13",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "CPER",
                    "siteDescription": "Central Plains Experimental Range NEON",
                    "siteType": "CORE",
                    "siteLatitude": 40.815536,
                    "siteLongitude": -104.745591,
                    "domainCode": "D10",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "CRAM",
                    "siteDescription": "Crampton Lake NEON",
                    "siteType": "CORE",
                    "siteLatitude": 46.209675,
                    "siteLongitude": -89.473688,
                    "domainCode": "D05",
                    "stateCode": "WI",
                },
                {
                    "siteCode": "CUPE",
                    "siteDescription": "Rio Cupeyes NEON",
                    "siteType": "CORE",
                    "siteLatitude": 18.11352,
                    "siteLongitude": -66.98676,
                    "domainCode": "D04",
                    "stateCode": "PR",
                },
                {
                    "siteCode": "DCFS",
                    "siteDescription": "Dakota Coteau Field  NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 47.16165,
                    "siteLongitude": -99.10656,
                    "domainCode": "D09",
                    "stateCode": "ND",
                },
                {
                    "siteCode": "DEJU",
                    "siteDescription": "Delta Junction NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 63.88112,
                    "siteLongitude": -145.75136,
                    "domainCode": "D19",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "DELA",
                    "siteDescription": "Dead Lake NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 32.541727,
                    "siteLongitude": -87.803877,
                    "domainCode": "D08",
                    "stateCode": "AL",
                },
                {
                    "siteCode": "DSNY",
                    "siteDescription": "Disney Wilderness Preserve NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 28.12505,
                    "siteLongitude": -81.43619,
                    "domainCode": "D03",
                    "stateCode": "FL",
                },
                {
                    "siteCode": "FLNT",
                    "siteDescription": "Flint River NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 31.185424,
                    "siteLongitude": -84.437403,
                    "domainCode": "D03",
                    "stateCode": "GA",
                },
                {
                    "siteCode": "GRSM",
                    "siteDescription": "Great Smoky Mountains National Park NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 35.68896,
                    "siteLongitude": -83.50195,
                    "domainCode": "D07",
                    "stateCode": "TN",
                },
                {
                    "siteCode": "GUAN",
                    "siteDescription": "Guanica Forest NEON",
                    "siteType": "CORE",
                    "siteLatitude": 17.96955,
                    "siteLongitude": -66.8687,
                    "domainCode": "D04",
                    "stateCode": "PR",
                },
                {
                    "siteCode": "GUIL",
                    "siteDescription": "Rio Yahuecas NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 18.17406,
                    "siteLongitude": -66.79868,
                    "domainCode": "D04",
                    "stateCode": "PR",
                },
                {
                    "siteCode": "HARV",
                    "siteDescription": "Harvard Forest & Quabbin Watershed NEON",
                    "siteType": "CORE",
                    "siteLatitude": 42.53691,
                    "siteLongitude": -72.17265,
                    "domainCode": "D01",
                    "stateCode": "MA",
                },
                {
                    "siteCode": "HEAL",
                    "siteDescription": "Healy NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 63.875798,
                    "siteLongitude": -149.213347,
                    "domainCode": "D19",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "HOPB",
                    "siteDescription": "Lower Hop Brook NEON",
                    "siteType": "CORE",
                    "siteLatitude": 42.471941,
                    "siteLongitude": -72.329526,
                    "domainCode": "D01",
                    "stateCode": "MA",
                },
                {
                    "siteCode": "JERC",
                    "siteDescription": "The Jones Center At Ichauway NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 31.194839,
                    "siteLongitude": -84.468623,
                    "domainCode": "D03",
                    "stateCode": "GA",
                },
                {
                    "siteCode": "JORN",
                    "siteDescription": "Jornada Experimental Range NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 32.590694,
                    "siteLongitude": -106.842542,
                    "domainCode": "D14",
                    "stateCode": "NM",
                },
                {
                    "siteCode": "KING",
                    "siteDescription": "Kings Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 39.105061,
                    "siteLongitude": -96.603829,
                    "domainCode": "D06",
                    "stateCode": "KS",
                },
                {
                    "siteCode": "KONA",
                    "siteDescription": "Konza Prairie Agroecosystem NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 39.110446,
                    "siteLongitude": -96.612935,
                    "domainCode": "D06",
                    "stateCode": "KS",
                },
                {
                    "siteCode": "KONZ",
                    "siteDescription": "Konza Prairie Biological Station NEON",
                    "siteType": "CORE",
                    "siteLatitude": 39.100774,
                    "siteLongitude": -96.563075,
                    "domainCode": "D06",
                    "stateCode": "KS",
                },
                {
                    "siteCode": "LAJA",
                    "siteDescription": "Lajas Experimental Station NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 18.021261,
                    "siteLongitude": -67.076889,
                    "domainCode": "D04",
                    "stateCode": "PR",
                },
                {
                    "siteCode": "LECO",
                    "siteDescription": "LeConte Creek NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 35.690428,
                    "siteLongitude": -83.50379,
                    "domainCode": "D07",
                    "stateCode": "TN",
                },
                {
                    "siteCode": "LENO",
                    "siteDescription": "Lenoir Landing NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 31.853861,
                    "siteLongitude": -88.161181,
                    "domainCode": "D08",
                    "stateCode": "AL",
                },
                {
                    "siteCode": "LEWI",
                    "siteDescription": "Lewis Run NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 39.095637,
                    "siteLongitude": -77.983216,
                    "domainCode": "D02",
                    "stateCode": "VA",
                },
                {
                    "siteCode": "LIRO",
                    "siteDescription": "Little Rock Lake NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 45.998269,
                    "siteLongitude": -89.704767,
                    "domainCode": "D05",
                    "stateCode": "WI",
                },
                {
                    "siteCode": "MART",
                    "siteDescription": "Martha Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 45.790835,
                    "siteLongitude": -121.933788,
                    "domainCode": "D16",
                    "stateCode": "WA",
                },
                {
                    "siteCode": "MAYF",
                    "siteDescription": "Mayfield Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 32.960365,
                    "siteLongitude": -87.407688,
                    "domainCode": "D08",
                    "stateCode": "AL",
                },
                {
                    "siteCode": "MCDI",
                    "siteDescription": "McDiffett Creek NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 38.945861,
                    "siteLongitude": -96.443022,
                    "domainCode": "D06",
                    "stateCode": "KS",
                },
                {
                    "siteCode": "MCRA",
                    "siteDescription": "McRae Creek NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 44.259598,
                    "siteLongitude": -122.165554,
                    "domainCode": "D16",
                    "stateCode": "OR",
                },
                {
                    "siteCode": "MLBS",
                    "siteDescription": "Mountain Lake Biological Station NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 37.378314,
                    "siteLongitude": -80.524847,
                    "domainCode": "D07",
                    "stateCode": "VA",
                },
                {
                    "siteCode": "MOAB",
                    "siteDescription": "Moab NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 38.248283,
                    "siteLongitude": -109.388273,
                    "domainCode": "D13",
                    "stateCode": "UT",
                },
                {
                    "siteCode": "NIWO",
                    "siteDescription": "Niwot Ridge NEON",
                    "siteType": "CORE",
                    "siteLatitude": 40.05425,
                    "siteLongitude": -105.58237,
                    "domainCode": "D13",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "NOGP",
                    "siteDescription": "Northern Great Plains Research Laboratory NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 46.76972,
                    "siteLongitude": -100.91535,
                    "domainCode": "D09",
                    "stateCode": "ND",
                },
                {
                    "siteCode": "OAES",
                    "siteDescription": "Marvin Klemme Range Research Station NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 35.410599,
                    "siteLongitude": -99.058779,
                    "domainCode": "D11",
                    "stateCode": "OK",
                },
                {
                    "siteCode": "OKSR",
                    "siteDescription": "Oksrukuyik Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 68.669753,
                    "siteLongitude": -149.143018,
                    "domainCode": "D18",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "ONAQ",
                    "siteDescription": "Onaqui NEON",
                    "siteType": "CORE",
                    "siteLatitude": 40.177599,
                    "siteLongitude": -112.452452,
                    "domainCode": "D15",
                    "stateCode": "UT",
                },
                {
                    "siteCode": "ORNL",
                    "siteDescription": "Oak Ridge NEON",
                    "siteType": "CORE",
                    "siteLatitude": 35.964128,
                    "siteLongitude": -84.282588,
                    "domainCode": "D07",
                    "stateCode": "TN",
                },
                {
                    "siteCode": "OSBS",
                    "siteDescription": "Ordway-Swisher Biological Station NEON",
                    "siteType": "CORE",
                    "siteLatitude": 29.689282,
                    "siteLongitude": -81.993431,
                    "domainCode": "D03",
                    "stateCode": "FL",
                },
                {
                    "siteCode": "POSE",
                    "siteDescription": "Posey Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 38.89431,
                    "siteLongitude": -78.147258,
                    "domainCode": "D02",
                    "stateCode": "VA",
                },
                {
                    "siteCode": "PRIN",
                    "siteDescription": "Pringle Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 33.378517,
                    "siteLongitude": -97.782312,
                    "domainCode": "D11",
                    "stateCode": "TX",
                },
                {
                    "siteCode": "PRLA",
                    "siteDescription": "Prairie Lake NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 47.15909,
                    "siteLongitude": -99.11388,
                    "domainCode": "D09",
                    "stateCode": "ND",
                },
                {
                    "siteCode": "PRPO",
                    "siteDescription": "Prairie Pothole NEON",
                    "siteType": "CORE",
                    "siteLatitude": 47.129839,
                    "siteLongitude": -99.253147,
                    "domainCode": "D09",
                    "stateCode": "ND",
                },
                {
                    "siteCode": "PUUM",
                    "siteDescription": "Puu Makaala Natural Area Reserve NEON",
                    "siteType": "CORE",
                    "siteLatitude": 19.55309,
                    "siteLongitude": -155.31731,
                    "domainCode": "D20",
                    "stateCode": "HI",
                },
                {
                    "siteCode": "REDB",
                    "siteDescription": "Red Butte Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 40.783934,
                    "siteLongitude": -111.797887,
                    "domainCode": "D15",
                    "stateCode": "UT",
                },
                {
                    "siteCode": "RMNP",
                    "siteDescription": "Rocky Mountains NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 40.275903,
                    "siteLongitude": -105.545955,
                    "domainCode": "D10",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "SCBI",
                    "siteDescription": "Smithsonian Conservation Biology Institute NEON",
                    "siteType": "CORE",
                    "siteLatitude": 38.892925,
                    "siteLongitude": -78.139494,
                    "domainCode": "D02",
                    "stateCode": "VA",
                },
                {
                    "siteCode": "SERC",
                    "siteDescription": "Smithsonian Environmental Research Center NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 38.890131,
                    "siteLongitude": -76.560014,
                    "domainCode": "D02",
                    "stateCode": "MD",
                },
                {
                    "siteCode": "SJER",
                    "siteDescription": "San Joaquin Experimental Range NEON",
                    "siteType": "CORE",
                    "siteLatitude": 37.10878,
                    "siteLongitude": -119.73228,
                    "domainCode": "D17",
                    "stateCode": "CA",
                },
                {
                    "siteCode": "SOAP",
                    "siteDescription": "Soaproot Saddle NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 37.03337,
                    "siteLongitude": -119.26219,
                    "domainCode": "D17",
                    "stateCode": "CA",
                },
                {
                    "siteCode": "SRER",
                    "siteDescription": "Santa Rita Experimental Range NEON",
                    "siteType": "CORE",
                    "siteLatitude": 31.91068,
                    "siteLongitude": -110.83549,
                    "domainCode": "D14",
                    "stateCode": "AZ",
                },
                {
                    "siteCode": "STEI",
                    "siteDescription": "Steigerwaldt-Chequamegon NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 45.50894,
                    "siteLongitude": -89.58637,
                    "domainCode": "D05",
                    "stateCode": "WI",
                },
                {
                    "siteCode": "STER",
                    "siteDescription": "North Sterling NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 40.461894,
                    "siteLongitude": -103.02929,
                    "domainCode": "D10",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "SUGG",
                    "siteDescription": "Lake Suggs NEON",
                    "siteType": "CORE",
                    "siteLatitude": 29.68778,
                    "siteLongitude": -82.017745,
                    "domainCode": "D03",
                    "stateCode": "FL",
                },
                {
                    "siteCode": "SYCA",
                    "siteDescription": "Sycamore Creek NEON",
                    "siteType": "CORE",
                    "siteLatitude": 33.750993,
                    "siteLongitude": -111.508091,
                    "domainCode": "D14",
                    "stateCode": "AZ",
                },
                {
                    "siteCode": "TALL",
                    "siteDescription": "Talladega National Forest NEON",
                    "siteType": "CORE",
                    "siteLatitude": 32.95047,
                    "siteLongitude": -87.393259,
                    "domainCode": "D08",
                    "stateCode": "AL",
                },
                {
                    "siteCode": "TEAK",
                    "siteDescription": "Lower Teakettle NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 37.00583,
                    "siteLongitude": -119.00602,
                    "domainCode": "D17",
                    "stateCode": "CA",
                },
                {
                    "siteCode": "TECR",
                    "siteDescription": "Teakettle Creek - Watershed 2 NEON",
                    "siteType": "CORE",
                    "siteLatitude": 36.955931,
                    "siteLongitude": -119.027363,
                    "domainCode": "D17",
                    "stateCode": "CA",
                },
                {
                    "siteCode": "TOMB",
                    "siteDescription": "Lower Tombigbee River NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 31.853431,
                    "siteLongitude": -88.158872,
                    "domainCode": "D08",
                    "stateCode": "AL",
                },
                {
                    "siteCode": "TOOK",
                    "siteDescription": "Toolik Lake NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 68.630692,
                    "siteLongitude": -149.610636,
                    "domainCode": "D18",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "TOOL",
                    "siteDescription": "Toolik Field Station NEON",
                    "siteType": "CORE",
                    "siteLatitude": 68.66109,
                    "siteLongitude": -149.37047,
                    "domainCode": "D18",
                    "stateCode": "AK",
                },
                {
                    "siteCode": "TREE",
                    "siteDescription": "Treehaven NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 45.49369,
                    "siteLongitude": -89.58571,
                    "domainCode": "D05",
                    "stateCode": "WI",
                },
                {
                    "siteCode": "UKFS",
                    "siteDescription": "KU Field Station NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 39.040431,
                    "siteLongitude": -95.19215,
                    "domainCode": "D06",
                    "stateCode": "KS",
                },
                {
                    "siteCode": "UNDE",
                    "siteDescription": "University of Notre Dame Environmental Research Center NEON",
                    "siteType": "CORE",
                    "siteLatitude": 46.23391,
                    "siteLongitude": -89.537254,
                    "domainCode": "D05",
                    "stateCode": "MI",
                },
                {
                    "siteCode": "WALK",
                    "siteDescription": "Walker Branch NEON",
                    "siteType": "CORE",
                    "siteLatitude": 35.957378,
                    "siteLongitude": -84.279251,
                    "domainCode": "D07",
                    "stateCode": "TN",
                },
                {
                    "siteCode": "WLOU",
                    "siteDescription": "West St Louis Creek NEON",
                    "siteType": "GRADIENT",
                    "siteLatitude": 39.891366,
                    "siteLongitude": -105.915395,
                    "domainCode": "D13",
                    "stateCode": "CO",
                },
                {
                    "siteCode": "WOOD",
                    "siteDescription": "Chase Lake National Wildlife Refuge NEON",
                    "siteType": "CORE",
                    "siteLatitude": 47.1282,
                    "siteLongitude": -99.241334,
                    "domainCode": "D09",
                    "stateCode": "ND",
                },
                {
                    "siteCode": "WREF",
                    "siteDescription": "Wind River Experimental Forest NEON",
                    "siteType": "CORE",
                    "siteLatitude": 45.82049,
                    "siteLongitude": -121.95191,
                    "domainCode": "D16",
                    "stateCode": "WA",
                },
                {
                    "siteCode": "YELL",
                    "siteDescription": "Yellowstone National Park NEON",
                    "siteType": "CORE",
                    "siteLatitude": 44.95348,
                    "siteLongitude": -110.53914,
                    "domainCode": "D12",
                    "stateCode": "WY",
                },
            ]
        }
    }
